@@ -6,6 +6,8 @@ $CPAN::Config = {
                                 'make_install_make_command' => q[make],
                                 'mbuild_install_build_command' => q[./Build],
                                ),
+		 'QAZWSX' => q[PLMOKN],
+                 'auto_commit' => q[0],
                  'build_cache' => q[100],
                  'build_dir' => qq[$cwd/t/dot-cpan/build],
                  #'bzip2' => q[/bin/bzip2],
